@@ -4,16 +4,16 @@ import snow_pyrepl as pyrepl
 from typing import Optional
 from replit.database import Database
 import getpass
-from datauri import DataURI
+import datauri
 from watchdog.observers import Observer
 from watchdog.events import LoggingEventHandler
 
-__version__ = "1.2.2"
+__version__ = "1.2.3"
 homedir = Path.home()
 homedir = str(homedir).replace("\\", "/")
 
 try:
-	__sid__ = open(f"{homedir}/replit-cli/connect.sid", "r").read().strip()
+	__sid__ = open(f"{homedir}/repl-cli/connect.sid", "r").read().strip()
 except:
 	__sid__ = None
 
@@ -126,15 +126,15 @@ def downloadRepl(user, replname):
 			original = content
 			content = clean(content)
 	
-			filename = user+"/"+replname+"/"+newfile
+			filename = replname+"/"+newfile
 			os.makedirs(os.path.dirname(filename), exist_ok=True)
 	
 			if ".png" in newfile or ".jpg" in newfile or ".webp" in newfile or ".gif" in newfile or ".jpeg" in newfile:
 				try:
-					uri = DataURI(content)
+					uri = datauri.parse(content)
 				except Exception as e:
 					content = clean(original, join=True)
-					uri = DataURI(content)
+					uri = datauri.parse(content)
 	
 					
 				fd = open(filename, 'wb')
@@ -154,7 +154,7 @@ def callback(ctx: typer.Context):
 	cmd = ctx.invoked_subcommand
 	listofcmds = ["clone", "env", "pull", "push", "exec", "shell", "run"]
 	if cmd in listofcmds:
-		if not os.path.exists(f"{homedir}/replit-cli/connect.sid"):
+		if not os.path.exists(f"{homedir}/repl-cli/connect.sid"):
 			typer.echo("You have not authenticated with Replit CLI yet. To run that command, first run the following command-\nreplit login --help")
 			raise typer.Exit()
 
@@ -170,11 +170,10 @@ def clone(repl:str=typer.Argument("", help="The URL of the repl which is to be c
 
 	user = repl.split("/")[0]
 	replname = repl.split("/")[1]
-	os.mkdir(replname)
-	os.system("cd "+replname)
+	slug = repl
 	downloadRepl(user, replname)
 	f = open(f"{replname}/.replitcliconfig", "w")
-	r = requests.get(f"https://replit.com/data/repls/@{slug}", cookies={"connect.sid": sid}).json()
+	r = requests.get(f"https://replit.com/data/repls/@{slug}", cookies={"connect.sid": __sid__}).json()
 	id = r['id']
 	print(f"""url=https://replit.com/@{slug}\nid={id}""", file=f)
 	f.close()
@@ -201,13 +200,10 @@ def pull(override:bool=False):
 
 		f = open(f".replitcliconfig", "w")
 		slug = url.split("/@")[-1]
-		r = requests.get(f"https://replit.com/data/repls/@{slug}", cookies={"connect.sid": sid}).json()
+		r = requests.get(f"https://replit.com/data/repls/@{slug}", cookies={"connect.sid": __sid__}).json()
 		id = r['id']
 		print(f"""url={url}\nid={id}""", file=f)
 		f.close()
-		f = open(f"connect.sid", "w")
-		print(f"""{sid}""", file=f)
-		f.close()
 	else:
 		f = open(".replitcliconfig", "r")
 		content = f.read()
@@ -428,9 +424,9 @@ def push(override:bool=False):
 @app.command(help="Authenticate with Replit CLI.\n\nTo get your SID value, check the cookie named 'connect.sid' when you visit Replit in your browser.")
 def login(sid:str=None):
 	if sid != None:
-		if not os.path.exists(f"{homedir}/replit-cli"):
-			os.mkdir(f"{homedir}/replit-cli")
-		f = open(f"{homedir}/replit-cli/connect.sid", "w")
+		if not os.path.exists(f"{homedir}/repl-cli"):
+			os.mkdir(f"{homedir}/repl-cli")
+		f = open(f"{homedir}/repl-cli/connect.sid", "w")
 		print(f"""{sid}""", file=f)
 		f.close()
 		typer.echo(f"Your SID value has been set as {sid}")
@@ -468,9 +464,9 @@ def login(sid:str=None):
 		typer.echo(f"Error! An unexpected error ocurred: HTTP Status was not 200. Received status was {r.status_code}")
 		return
 
-	if not os.path.exists(f"{homedir}/replit-cli"):
-		os.mkdir(f"{homedir}/replit-cli")
-	f = open(f"{homedir}/replit-cli/connect.sid", "w")
+	if not os.path.exists(f"{homedir}/repl-cli"):
+		os.mkdir(f"{homedir}/repl-cli")
+	f = open(f"{homedir}/repl-cli/connect.sid", "w")
 	print(f"""{sid}""", file=f)
 	f.close()
 	typer.echo(f"Your SID value has been set as {sid}")
